@@ -15,6 +15,9 @@ declare function createXeusModule(options: any): any;
 
 globalThis.Module = {};
 
+const WASM_KERNEL_FILE = './xpython_wasm.js';
+const DATA_FILE = './python_data.js';
+
 // TODO Remove this. This is to ensure we always perform node ops on Nodes and
 // not Streams, but why is it needed??? Why do we get Streams and not Nodes from
 // emscripten in the case of xeus-python???
@@ -95,7 +98,7 @@ async function get_stdin() {
 
 (self as any).get_stdin = get_stdin;
 
-class XeusPythonKernel {
+class XeusKernel {
   constructor() {
     this._ready = new Promise(resolve => {
       this.initialize(resolve);
@@ -109,6 +112,10 @@ class XeusPythonKernel {
   mount(driveName: string, mountpoint: string, baseUrl: string): void {
     const { FS, PATH, ERRNO_CODES } = globalThis.Module;
 
+    if (!FS) {
+      return;
+    }
+
     this._drive = new LoggingDrive({
       FS,
       PATH,
@@ -124,7 +131,7 @@ class XeusPythonKernel {
   }
 
   cd(path: string) {
-    if (!path) {
+    if (!path || !globalThis.Module.FS) {
       return;
     }
 
@@ -154,13 +161,14 @@ class XeusPythonKernel {
   }
 
   private async initialize(resolve: () => void) {
-    importScripts('./xpython_wasm.js');
+    importScripts(WASM_KERNEL_FILE);
 
     globalThis.Module = await createXeusModule({});
 
-    importScripts('./python_data.js');
-
-    await this.waitRunDependency();
+    if (DATA_FILE.length !== 0) {
+      importScripts(DATA_FILE);
+      await this.waitRunDependency();
+    }
 
     this._raw_xkernel = new globalThis.Module.xkernel();
     this._raw_xserver = this._raw_xkernel.get_server();
@@ -196,4 +204,4 @@ class XeusPythonKernel {
   private _ready: PromiseLike<void>;
 }
 
-expose(new XeusPythonKernel());
+expose(new XeusKernel());
